<?php

namespace Gateway;

use Config\ConnectClass;
use Config\Connection;
use PDO;
use PDOException;

class GatewayForm
{
    private Connection $connection;

    public function __construct()
    {
        try{
            $this->connection = (new ConnectClass)->connect();
        }catch(PDOException $e){
            throw new PDOException($e->getMessage(), $e->getCode(), $e);
        }
    }

    public function insertForm(string $title, string $description): void
    {
        if(empty($this->getForm()))
        {
            $query = "INSERT INTO Form(title, description) VALUES(:title, :description)";
            $this->connection->executeQuery($query, array(
                ':title' => array($title, PDO::PARAM_STR),
                ':description' => array($description, PDO::PARAM_STR)
            ));
        }
    }

    public function getForm(): array
    {
        $query = "SELECT * FROM `form`";
        $this->connection->executeQuery($query);
        return $this->connection->getResults();
    }

    public function deleteForm(array $idform): void
    {
        $query = "DELETE FROM Form WHERE id = :id";
        $this->connection->executeQuery($query, array(
            ':id' => array($idform[0], PDO::PARAM_INT)
        ));
    }

    public function assignKeywordToQuestion(string $keyword, int $idQuestion, string $response): void
    {
        $query = "SELECT pr.id
                  FROM Propose p, PossibleResponse pr
                  WHERE p.question = :id AND p.possibleResponse = pr.id
                        AND pr.content = :response";
        $this->connection->executeQuery($query, array(
            ':id' => array($idQuestion, PDO::PARAM_INT),
            ':response' => array($response, PDO::PARAM_STR)
        ));

        $idPossibleResponse = $this->connection->getResults()[0][0];

        $query = "INSERT INTO Reference(possibleResponse, keyword) VALUES(:possibleResponse, :keyword)";
        $this->connection->executeQuery($query, array(
            ':possibleResponse' => array($idPossibleResponse, PDO::PARAM_INT),
            ':keyword' => array($keyword, PDO::PARAM_STR)
        ));
    }

    public function deleteKeywordFromQuestion(string $keyword, int $idQuestion, string $response): void
    {
        $query = "SELECT pr.id FROM Propose p, PossibleResponse r
                  WHERE p.question = :id AND p.possibleResponse = pr.id
                        AND pr.content = :response";
        $this->connection->executeQuery($query, array(
            ':id' => array($idQuestion, PDO::PARAM_INT),
            ':response' => array($response, PDO::PARAM_STR)
        ));

        $idPossibleResponse = $this->connection->getResults()[0][0];

        $query = "DELETE FROM Reference WHERE response = :idResponse AND keyword = :idKeyword";
        $this->connection->executeQuery($query, array(
            ':idResponse' => array($idPossibleResponse, PDO::PARAM_INT),
            ':idKeyword' => array($keyword, PDO::PARAM_INT)
        ));
    }

    public function updateTitleToForm(int $id, string $title): void
    {
        $query = "UPDATE Form SET title = :title WHERE id = :id";
        $this->connection->executeQuery($query, array(
            ':title' => array($title, PDO::PARAM_STR),
            ':id' => array($id, PDO::PARAM_INT)
        ));
    }

    public function updateDescriptionToForm(int $id, string $description): void
    {
        $query = "UPDATE Form SET title = :title WHERE description = :description";
        $this->connection->executeQuery($query, array(
            ':description' => array($description, PDO::PARAM_STR),
            ':id' => array($id, PDO::PARAM_INT)
        ));
    }

    public function deleteDescriptionToForm(int $idForm): void
    {
        $query = "UPDATE Form SET title = :title WHERE description = :description";
        $this->connection->executeQuery($query, array(
            ':description' => array('', PDO::PARAM_STR),
            ':id' => array($idForm, PDO::PARAM_INT)
        ));
    }

    public function existsForm(): bool
    {
        $query = "SELECT * FROM Form";
        $this->connection->executeQuery($query);
        return !empty($this->connection->getResults());
    }
}
